# -*- coding: cp1252 -*-

import os, sys
from os.path import join, isdir

avrs = []
srcdirs = []
subdirs = []
csrcfiles = []
cppsrcfiles = []
options = []

def printHeader(text):
		print ""
		print "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
		print "XXX "  + text
		print "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
		
def readFile(name):
		f = open(name)
		lines = f.readlines()
		lns = []
		for line in lines:
				if not line.startswith("#"):
					# remove line break (win only?)
					lns.append(line[:-1])
		f.close()
		return lns

def readAvrTypes():
        ''' Read avr types as defined in buildTargets.conf '''
        lines = readFile("buildTargets.conf")
        for line in lines:
            avrs.append(line)
        
        
def readSrcDirs():
        ''' Read main source dirs as defined in buildTargetsSrcDirs.conf '''
        lines = readFile("buildTargetsSrcDirs.conf")
        for line in lines:
            srcdirs.append(line)
        for dir in srcdirs:
                findSrcSubdirs(dir)

def readOptions():
    ''' Read additional options '''
    lines = readFile("buildTargetsOptions.conf")
    for line in lines:
        options.append(line)
    

def findSrcSubdirs(srcdir):
        ''' Find all subdirs of the sourcedir provided '''
        items  = os.listdir(srcdir)
        for item in items:
                if isdir(join(srcdir, item)) and not item[0:1] == ".":
                         dir = srcdir + "/" + item
                         findSrcSubdirs(dir)
                         subdirs.append(dir)

def findCppFiles():
        for dir in subdirs:
                items = os.listdir(dir)                
                for item in items:
                        if (not isdir(item)) and item.endswith(".cpp"):
                                cppsrcfiles.append(dir + "/" + item)

def findCFiles():
        for dir in subdirs:
                items = os.listdir(dir)                
                for item in items:
                        if (not isdir(item)) and item.endswith(".c"):
                                csrcfiles.append(dir + "/" + item)

def runMakeTest(avr):
        ''' Run the make test for the avr architecture provided '''

        printHeader("Calling make for target " + avr)

        SUBDIRS =  '"' + " ".join(subdirs) + '"'
        MCU = avr
        CSRC = '"' + ' '.join(csrcfiles)+ '"'
        CPPSRC = '"' + ' '.join(cppsrcfiles)+ '"'
        opts = " ".join(options)

        # build the command
        command = "make SUBDIRS=" + SUBDIRS + " " + opts + " MCU=" + MCU + " CPPSRC=" + CPPSRC + " SRC=" + CSRC + " library"

        # execute the command
        os.system("make clean")
        print(command)
        sts = os.system(command)
        if sts != 0:
        	printHeader("Target " + avr + " has errors. Terminating")
        	sys.exit()
        

readAvrTypes()
readSrcDirs()
readOptions()
findCFiles()
findCppFiles()

for avr in avrs:
        runMakeTest(avr)
        
os.system("make clean")





